@@ -23,9 +23,16 @@ from aliyunsdkdms_enterprise.endpoint import endpoint_data
 class GetUserActiveTenantRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'GetUserActiveTenant','dmsenterprise')
+		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'GetUserActiveTenant','dms-enterprise')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Tid(self): # Long
+		return self.get_query_params().get('Tid')
+
+	def set_Tid(self, Tid):  # Long
+		self.add_query_param('Tid', Tid)
